import logging

from sendmail import sendmail
from zenutils import importutils

from .settings import DJANGO_SITE_WARNING_NOTIFY_MAIL_CONFIG
from .settings import DJANGO_SITE_WARNING_NOTIFY_MAIL_FROM
from .settings import DJANGO_SITE_WARNING_NOTIFY_MAIL_TO
from .settings import DJANGO_SITE_WARNING_NOTIFY_MAIL_SERVER
from .settings import DJANGO_SITE_WARNING_NOTIFY_MAIL_PORT
from .settings import DJANGO_SITE_WARNING_NOTIFY_MAIL_SSL
from .settings import DJANGO_SITE_WARNING_NOTIFY_MAIL_USER
from .settings import DJANGO_SITE_WARNING_NOTIFY_MAIL_PASSWORD

_logger = logging.getLogger(__name__)


def sendmail_notify(warning, payload, force):
    _logger.debug(
        "django-site-warnings doing sendmail_notify...",
    )

    config = DJANGO_SITE_WARNING_NOTIFY_MAIL_CONFIG
    if config and isinstance(config, str):
        config_callback = importutils.import_from_string(config)
        if config_callback and callable(config_callback):
            config = config_callback(warning, payload, force)
    if not config:
        config = {
            "from_address": DJANGO_SITE_WARNING_NOTIFY_MAIL_FROM,
            "to_addresses": DJANGO_SITE_WARNING_NOTIFY_MAIL_TO,
            "server": DJANGO_SITE_WARNING_NOTIFY_MAIL_SERVER,
            "port": DJANGO_SITE_WARNING_NOTIFY_MAIL_PORT,
            "ssl": DJANGO_SITE_WARNING_NOTIFY_MAIL_SSL,
            "user": DJANGO_SITE_WARNING_NOTIFY_MAIL_USER,
            "password": DJANGO_SITE_WARNING_NOTIFY_MAIL_PASSWORD,
        }

    _logger.debug(
        "django-site-warnings doing sendmail_notify with config: %s",
        config,
    )

    subject = warning.get_notify_email_subject()
    content = warning.get_notify_email_content()

    sendmail(
        config["from_address"],
        config["to_addresses"],
        content,
        subject,
        attachs=None,
        is_html_content=True,
        encoding="utf-8",
        charset="utf-8",
        host=config["server"],
        port=config.get("port", 465),
        ssl=config.get("ssl", True),
        user=config["user"],
        password=config["password"],
    )



from zenutils import importutils

from django.contrib import admin
from django.utils.translation import gettext_lazy as _
from django.conf import settings

from django_simpletask2.actions import reset_selected_tasks as reset_selected_tasks_core
from django_simpletask2.actions import (
    force_do_selected_tasks as force_do_selected_tasks_core,
)
from django_simpletask2.actions import (
    mark_selected_tasks_done as mark_selected_tasks_done_core,
)

from .models import Warning
from .models import WaringCategory

from .actions import django_site_warnings_acknowledge
from .actions import django_site_warnings_deny

DjangoSiteWarningsBaseAdminName = getattr(
    settings, "DJANGO_SITE_WARNINGS_ADMIN_BASE", "django.contrib.admin.ModelAdmin"
)
DjangoSiteWarningsBaseAdmin = importutils.import_from_string(
    DjangoSiteWarningsBaseAdminName
)
if not DjangoSiteWarningsBaseAdmin:
    DjangoSiteWarningsBaseAdmin = admin.ModelAdmin


def reset_selected_tasks(*args, **kwargs):
    return reset_selected_tasks_core(*args, **kwargs)


reset_selected_tasks.short_description = _("Reset Warning Message Sending Status")


def force_do_selected_tasks(*args, **kwargs):
    return force_do_selected_tasks_core(*args, **kwargs)


force_do_selected_tasks.short_description = _("Force To Send Warning Message")


def mark_selected_tasks_done(*args, **kwargs):
    return mark_selected_tasks_done_core(*args, **kwargs)


mark_selected_tasks_done.short_description = _(
    "Mark Select Warning Message Already Sent"
)


class WaringCategoryAdmin(DjangoSiteWarningsBaseAdmin):
    list_display = ["name", "code"]
    ordering = ["display_order"]


class WarningAdmin(DjangoSiteWarningsBaseAdmin):
    list_display = ["title", "add_time", "status", "success", "ack"]
    list_filter = ["category", "status", "ack"]
    readonly_fields = [] + Warning.SIMPLE_TASK_FIELDS

    actions = [
        django_site_warnings_acknowledge,
        django_site_warnings_deny,
        reset_selected_tasks,
        force_do_selected_tasks,
        mark_selected_tasks_done,
    ]


admin.site.register(WaringCategory, WaringCategoryAdmin)
admin.site.register(Warning, WarningAdmin)



from django.conf import settings

DJANGO_SITE_WARNING_NOTIFY_MAIL_CONFIG = getattr(
    settings,
    "DJANGO_SITE_WARNING_NOTIFY_MAIL_CONFIG",
    None,
)
DJANGO_SITE_WARNING_NOTIFY_MAIL_FROM = getattr(
    settings,
    "DJANGO_SITE_WARNING_NOTIFY_MAIL_FROM",
    None,
)
DJANGO_SITE_WARNING_NOTIFY_MAIL_TO = getattr(
    settings,
    "DJANGO_SITE_WARNING_NOTIFY_MAIL_TO",
    None,
)
DJANGO_SITE_WARNING_NOTIFY_MAIL_SERVER = getattr(
    settings,
    "DJANGO_SITE_WARNING_NOTIFY_MAIL_SERVER",
    None,
)
DJANGO_SITE_WARNING_NOTIFY_MAIL_PORT = getattr(
    settings,
    "DJANGO_SITE_WARNING_NOTIFY_MAIL_PORT",
    465,
)
DJANGO_SITE_WARNING_NOTIFY_MAIL_SSL = getattr(
    settings,
    "DJANGO_SITE_WARNING_NOTIFY_MAIL_SSL",
    True,
)
DJANGO_SITE_WARNING_NOTIFY_MAIL_USER = getattr(
    settings,
    "DJANGO_SITE_WARNING_NOTIFY_MAIL_USER",
    None,
)
DJANGO_SITE_WARNING_NOTIFY_MAIL_PASSWORD = getattr(
    settings,
    "DJANGO_SITE_WARNING_NOTIFY_MAIL_PASSWORD",
    None,
)



# Generated by Django 3.2.22 on 2023-10-25 08:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_site_warnings', '0005_auto_20220310_1544'),
    ]

    operations = [
        migrations.AlterField(
            model_name='warning',
            name='status',
            field=models.IntegerField(choices=[(10, 'Message Not sent yet'), (20, 'Message is sending'), (30, 'Messgage Sent')], default=10, editable=False, verbose_name='Notify Status'),
        ),
        migrations.AlterField(
            model_name='warning',
            name='success',
            field=models.BooleanField(editable=False, null=True, verbose_name='Notify Sent Success'),
        ),
    ]
